@@ -1,9 +1,7 @@
-#include <Rcpp.h>
+#include "get_entropy.h"
 using namespace Rcpp;
-// [[Rcpp::interfaces(r, cpp)]]
 
-// [[Rcpp::export]]
-double rcpp_get_entropy(NumericVector x, std::string base = "log2") {
+double rcpp_get_entropy(NumericVector x, std::string base) {
         x = x / sum(x);
         double result = 0.0;
         for(int i = 0; i < x.size(); i++){
